==> nextcloud-app-tasks-0.9.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/ast.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Xeres",
    "Due yesterday" : "Venció ayeri",
    "Due today" : "Vencimientu güei",
    "Due tomorrow" : "Vencimientu mañana",
    "Due on" : "Vence en",
    "Started yesterday" : "Entamó ayeri",
    "Starts today" : "Entama güei",
    "Starts tomorrow" : "Entamará mañana",
    "Started on" : "Entamó en",
    "Starts on" : "Entama en",
    "[Remind me yesterday at ]HH:mm" : "[Recuérdame ayeri a les ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Recuérdamelo güei a les ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Recuérdame mañana a les ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Recuerdame'l ]MMM DD, YYYY,[ a les]HH:mm",
    "Yesterday" : "Ayeri",
    "Today" : "Güei",
    "Tomorrow" : "Mañana",
    "in %s" : "en %s",
    "%s ago" : "hai %s",
    "seconds" : "segundos",
    "a minute" : "un minutu",
    "%d minutes" : "%d minutos",
    "an hour" : "una hora",
    "%d hours" : "%d hores",
    "a day" : "un día",
    "%d days" : "%d díes",
    "a month" : "un mes",
    "%d months" : "%d meses",
    "a year" : "un añu",
    "%d years" : "%d años",
    "week" : "selmana",
    "weeks" : "selmanes",
    "day" : "día",
    "days" : "díes",
    "hour" : "hora",
    "hours" : "hores",
    "minute" : "minutu",
    "minutes" : "minutos",
    "second" : "segundu",
    "before beginning" : "Enantes del entamu",
    "after beginning" : "Dempués del entamu",
    "before end" : "Enantes del final",
    "after end" : "Dempués del final",
    "Comment" : "Comentariu",
    "Add a comment" : "Amestar un comentariu",
    "The name \"%s\" is already used." : "El nome \"%s\" yá ta usándose.",
    "An empty name is not allowed." : "Nun s'almite un nome baleru",
    "Hidden" : "Anubríu",
    "Visible" : "Visible",
    "Automatic" : "Automáticu",
    "Sunday" : "Domingu",
    "Monday" : "Llunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Xueves",
    "Friday" : "Vienres",
    "Saturday" : "Sábadu",
    "Add an important item in \"%s\"..." : "Amestar un elemtu importante en \"%s\"...",
    "Add an item due today in \"%s\"..." : "Amestar un elemtu vence güei en \"%s\"...",
    "Add an item in \"%s\"..." : "Amestar un elementu en \"%s\"...",
    "Add a current item in \"%s\"..." : "Amesta un elementu actual en \"%s\"...",
    "Add a subtask to \"%s\"..." : "Amestar una subxera en \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n xera completada","%n xeres completaes"],
    "Hours" : "Hores",
    "Minutes" : "Minutos",
    "Set due date" : "Afitar la data de caducidá",
    "%s %% completed" : "%s %% completáu",
    "priority %s: " : "prioridá %s:",
    "high" : "altu",
    "medium" : "mediu",
    "low" : "baxu",
    "no priority assigned" : "Nenguna prioridá asignada",
    "Remind me" : "Recuerdamelo",
    "at the end" : "al final",
    "at the beginning" : "al entamu",
    "Set start date" : "Afitar la fecha d'entamu",
    "{calendar} shared by {owner}" : "{calendar} compartíu por  {owner}",
    "Unnamed" : "Ensin nome",
    "Important" : "Importante",
    "Week" : "Selmana",
    "All" : "Toos",
    "Current" : "Actual",
    "Completed" : "Completáu",
    "Delete" : "Desaniciar",
    "Cancel" : "Encaboxar",
    "Edit" : "Editar",
    "Link" : "Enllaz",
    "Download" : "Baxar",
    "Save" : "Guardar",
    "Add List..." : "Amestar Llista...",
    "New List" : "Nueva Llista",
    "Settings" : "Axustes",
    "Start of week" : "Entamu de selmana",
    "Visibility of Smart Collections" : "Visibilidá de Coleiciones Intelixentes",
    "Change sort order" : "Camudar orde d'ordenación",
    "Default" : "Predetermináu",
    "Priority" : "Prioridá",
    "Alphabetically" : "Alfabéticamente",
    "Manually" : "A mano",
    "Load remaining completed tasks." : "Cargar el restante de xeres completaes.",
    "Task is completed" : "La xera ta completada",
    "All day" : "Tol día",
    "(New category)" : "(Nueva estaya)",
    "Select categories..." : "Seleicionar estayes...",
    "Loading the task..." : "Cargando la xera...",
    "Task not found!" : "¡Xera non atopada!",
    "add a subtask to" : "amestar una subxera a",
    "Toggle subtasks" : "Alternar soxeres",
    "Toggle completed subtasks" : "Alternar soxeres completaes"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-tasks-0.12.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/ast.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Importante",
    "Today" : "Güei",
    "Week" : "Selmana",
    "All" : "Toos",
    "Current" : "Actual",
    "Completed" : "Completáu",
    "Tasks" : "Xeres",
    "Share with users or groups" : "Compartir con usuarios y grupos",
    "can edit" : "pue editar",
    "New List" : "Nueva Llista",
    "Cancel" : "Encaboxar",
    "Save" : "Guardar",
    "An empty name is not allowed." : "Nun s'almite un nome baleru",
    "Edit" : "Editar",
    "Download" : "Baxar",
    "Delete" : "Desaniciar",
    "Unshare" : "Dexar de compartir",
    "Visibility of Smart Collections" : "Visibilidá de Coleiciones Intelixentes",
    "Hidden" : "Anubríu",
    "Visible" : "Visible",
    "Automatic" : "Automáticu",
    "Change sort order" : "Camudar orde d'ordenación",
    "Priority" : "Prioridá",
    "Manually" : "A mano",
    "Alphabetically" : "Alfabéticamente",
    "Task is completed" : "La xera ta completada",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n xera completada","%n xeres completaes"],
    "Tomorrow" : "Mañana",
    "Set start date" : "Afitar la fecha d'entamu",
    "Set due date" : "Afitar la data de caducidá",
    "All day" : "Tol día",
    "Task not found!" : "¡Xera non atopada!",
    "When shared show full event" : "Amosar l'eventu completu al compartir",
    "When shared show only busy" : "Amosar namás ocupáu al compartir",
    "When shared hide this event" : "Anubrir l'eventu al compartir"
},
"nplurals=2; plural=(n != 1);");
